@@ -168,6 +168,43 @@ def calc_wind_speed(wrf_xr):
 
 #     return t2
 
+def calc_avi(data):
+    """
+
+    """
+    u20 = data['u'].sel(height=20)
+    v20 = data['v'].sel(height=20)
+
+    ws = np.sqrt(u20**2 + v20**2)
+
+    avi = (ws * data['pblh'])
+    avi = xr.where(avi > 32000, 32000, avi)
+
+    return avi.expand_dims('height', axis=3)
+
+
+def calc_soil_temp(data, units='degC'):
+    """
+
+    """
+    t2 = data['soil_temp']
+
+    if units == 'degC':
+        t2 = t2 - 273.15
+    elif units != 'K':
+        raise ValueError('units must be either degC or K.')
+
+    return t2
+
+
+def calc_soil_water(data):
+    """
+
+    """
+    t2 = data['soil_water']
+
+    return t2
+
 
 def calc_temp(wrf_xr, units='degC'):
     """
@@ -380,7 +417,16 @@ func_dict = {
                         },
     'calc_ground_heat_flux_0': {'variables': ['ground_heat_flux'],
                         'function': calc_ground_heat_flux_0
-                        }
+                        },
+    'calc_soil_temp': {'variables': ['soil_temp'],
+                  'function': calc_soil_temp
+                  },
+    'calc_soil_water': {'variables': ['soil_water'],
+                  'function': calc_soil_water
+                  },
+    'calc_avi': {'variables': ['u', 'v', 'pblh'],
+                  'function': calc_avi
+                  },
     }
 
 
